Name:          certbot
Version:       3.0.0
Release:       1mamba
Summary:       A fully-featured, extensible client for the Let's Encrypt CA
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://letsencrypt.org
Source:        https://github.com/certbot/certbot.git/v%{version}/certbot-%{version}.tar.bz2
Source1:       certbot-renew.service
Source2:       certbot-renew.timer
License:       Apache License 2.0
## AUTOBUILDREQ-BEGIN
BuildRequires: (python3.11dist(pyopenssl) < 23.1 or python3.11dist(pyopenssl) > 23.1)
BuildRequires: libpython311-devel
BuildRequires: python3.11dist(acme)
BuildRequires: python3.11dist(configargparse)
BuildRequires: python3.11dist(configobj)
BuildRequires: python3.11dist(cryptography)
BuildRequires: python3.11dist(distro)
BuildRequires: python3.11dist(josepy)
BuildRequires: python3.11dist(parsedatetime)
BuildRequires: python3.11dist(pyopenssl)
BuildRequires: python3.11dist(pyparsing)
BuildRequires: python3.11dist(pyrfc3339)
BuildRequires: python3.11dist(python-augeas)
BuildRequires: python3.11dist(pytz)
BuildRequires: python3.11dist(setuptools)
## AUTOBUILDREQ-END
Requires:      python-psutil-py3
Requires:      python-requests-py3
Requires:      python-six-py3
Provides:      letsencrypt
Obsoletes:     letsencrypt < 1.31.0

%description
The Let's Encrypt Client is a fully-featured, extensible client for the Let's Encrypt CA (or any other CA that speaks the ACME protocol) that can automate the tasks of obtaining certificates and configuring webservers to use them.

%package apache
Group:         System/Libraries
Summary:       Apache plugin for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      apache

%description apache
The Let's Encrypt Client is a fully-featured, extensible client for the Let's Encrypt CA (or any other CA that speaks the ACME protocol) that can automate the tasks of obtaining certificates and configuring webservers to use them.
This package provides the Apache plugin.

%package nginx
Group:         System/Libraries
Summary:       Nginx plugin for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      nginx

%description nginx
The Let's Encrypt Client is a fully-featured, extensible client for the Let's Encrypt CA (or any other CA that speaks the ACME protocol) that can automate the tasks of obtaining certificates and configuring webservers to use them.
This package provides the Nginx plugin.

%prep
%setup -q

%build
for d in certbot certbot-{apache,nginx}; do
cd $d
CFLAGS="%{optflags}" %{__python3} -m build --no-isolation --wheel
cd ..
done

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
for d in certbot certbot-{apache,nginx}; do
cd $d
%{__python3} -m installer --destdir=%{buildroot} dist/*.whl
cd ..
done

install -d -m0755 %{buildroot}%{_sysconfdir}/letsencrypt
install -d -m0755 %{buildroot}%{_localstatedir}/log/letsencrypt

install -d -m0755 %{buildroot}%{_sysconfdir}/cron.weekly
cat > %{buildroot}%{_sysconfdir}/cron.weekly/certbot << _EOF
#!/bin/bash
# Using certbot-renew.timer but ensuring web servers reload at least once per week
systemctl -q is-enabled httpd >/dev/null && systemctl reload httpd
systemctl -q is-enabled nginx >/dev/null && systemctl reload nginx
_EOF

install -D -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/certbot-renew.service
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/certbot-renew.timer

%post
%systemd_post certbot-renew.timer
:

%preun
%systemd_preun certbot-renew.timer
:

%postun
%systemd_postun certbot-renew.timer
:

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/letsencrypt
%attr(0755,root,root) %{_sysconfdir}/cron.weekly/certbot
%{_bindir}/certbot
%attr(0700,root,root) %dir %{_localstatedir}/log/letsencrypt
%{_unitdir}/certbot-renew.service
%{_unitdir}/certbot-renew.timer
%dir %{python3_sitelib}/certbot-%{version}.dist-info
%{python3_sitelib}/certbot-%{version}.dist-info/*
%dir %{python3_sitelib}/certbot
%{python3_sitelib}/certbot/*
%doc LICENSE.txt

%files apache
%defattr(-,root,root)
%dir %{python3_sitelib}/certbot_apache-%{version}.dist-info
%{python3_sitelib}/certbot_apache-%{version}.dist-info/*
%dir %{python3_sitelib}/certbot_apache
%{python3_sitelib}/certbot_apache/*

%files nginx
%defattr(-,root,root)
%dir %{python3_sitelib}/certbot_nginx-%{version}.dist-info
%{python3_sitelib}/certbot_nginx-%{version}.dist-info/*
%dir %{python3_sitelib}/certbot_nginx
%{python3_sitelib}/certbot_nginx/*

%changelog
* Wed Nov 06 2024 Automatic Build System <autodist@openmamba.org> 3.0.0-1mamba
- automatic version update by autodist

* Thu Jun 06 2024 Automatic Build System <autodist@openmamba.org> 2.11.0-1mamba
- automatic version update by autodist

* Mon May 13 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.10.0-2mamba
- enable certbot-renew.timer, modify cron.weekly/certbot to only reload web servers

* Sat Apr 06 2024 Automatic Build System <autodist@openmamba.org> 2.10.0-1mamba
- automatic version update by autodist

* Sun Feb 11 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.0-2mamba
- rebuilt with python3 == 3.11

* Fri Feb 09 2024 Automatic Build System <autodist@openmamba.org> 2.9.0-1mamba
- automatic version update by autodist

* Thu Dec 07 2023 Automatic Build System <autodist@mambasoft.it> 2.8.0-1mamba
- automatic version update by autodist

* Wed Nov 01 2023 Automatic Build System <autodist@mambasoft.it> 2.7.4-1mamba
- automatic version update by autodist

* Thu Oct 26 2023 Automatic Build System <autodist@mambasoft.it> 2.7.3-1mamba
- automatic version update by autodist

* Fri Oct 20 2023 Automatic Build System <autodist@mambasoft.it> 2.7.2-1mamba
- automatic version update by autodist

* Tue Oct 10 2023 Automatic Build System <autodist@mambasoft.it> 2.7.1-1mamba
- automatic version update by autodist

* Wed Oct 04 2023 Automatic Build System <autodist@mambasoft.it> 2.7.0-1mamba
- automatic version update by autodist

* Tue Sep 26 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.0-4mamba
- added nginx plugin

* Tue Aug 15 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.0-3mamba
- update requirements with python 3.10

* Tue Jul 18 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.0-2mamba
- rebuilt with python 3.10

* Wed May 10 2023 Automatic Build System <autodist@mambasoft.it> 2.6.0-1mamba
- automatic version update by autodist

* Tue Apr 04 2023 Automatic Build System <autodist@mambasoft.it> 2.5.0-1mamba
- automatic version update by autodist

* Wed Mar 08 2023 Automatic Build System <autodist@mambasoft.it> 2.4.0-1mamba
- automatic version update by autodist

* Wed Feb 15 2023 Automatic Build System <autodist@mambasoft.it> 2.3.0-1mamba
- automatic version update by autodist

* Thu Jan 12 2023 Automatic Build System <autodist@mambasoft.it> 2.2.0-1mamba
- automatic version update by autodist

* Fri Dec 16 2022 Automatic Build System <autodist@mambasoft.it> 2.1.1-1mamba
- automatic version update by autodist

* Wed Dec 07 2022 Automatic Build System <autodist@mambasoft.it> 2.1.0-1mamba
- automatic version update by autodist

* Tue Nov 22 2022 Automatic Build System <autodist@mambasoft.it> 2.0.0-1mamba
- automatic version update by autodist

* Wed Nov 09 2022 Automatic Build System <autodist@mambasoft.it> 1.32.0-1mamba
- automatic version update by autodist

* Tue Oct 04 2022 Automatic Build System <autodist@mambasoft.it> 1.31.0-1mamba
- automatic version update by autodist

* Thu Sep 08 2022 Automatic Build System <autodist@mambasoft.it> 1.30.0-1mamba
- automatic version update by autodist

* Thu Jul 07 2022 Automatic Build System <autodist@mambasoft.it> 1.29.0-1mamba
- automatic version update by autodist

* Wed Jun 08 2022 Automatic Build System <autodist@mambasoft.it> 1.28.0-1mamba
- automatic version update by autodist

* Sat Jun 04 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 1.27.0-2mamba
- update croon.weekly with support for reloading nginx and/or httpd if enabled

* Wed May 04 2022 Automatic Build System <autodist@mambasoft.it> 1.27.0-1mamba
- automatic version update by autodist

* Wed Apr 06 2022 Automatic Build System <autodist@mambasoft.it> 1.26.0-1mamba
- automatic version update by autodist

* Wed Mar 16 2022 Automatic Build System <autodist@mambasoft.it> 1.25.0-1mamba
- automatic version update by autodist

* Wed Mar 02 2022 Automatic Build System <autodist@mambasoft.it> 1.24.0-1mamba
- automatic version update by autodist

* Wed Feb 09 2022 Automatic Build System <autodist@mambasoft.it> 1.23.0-1mamba
- automatic version update by autodist

* Wed Dec 08 2021 Automatic Build System <autodist@mambasoft.it> 1.22.0-1mamba
- automatic version update by autodist

* Wed Nov 03 2021 Automatic Build System <autodist@mambasoft.it> 1.21.0-1mamba
- automatic version update by autodist

* Tue Oct 05 2021 Automatic Build System <autodist@mambasoft.it> 1.20.0-1mamba
- automatic version update by autodist

* Wed Sep 08 2021 Automatic Build System <autodist@mambasoft.it> 1.19.0-1mamba
- automatic version update by autodist

* Wed Aug 04 2021 Automatic Build System <autodist@mambasoft.it> 1.18.0-1mamba
- automatic version update by autodist

* Wed Jul 07 2021 Automatic Build System <autodist@mambasoft.it> 1.17.0-1mamba
- automatic version update by autodist

* Wed Jun 02 2021 Automatic Build System <autodist@mambasoft.it> 1.16.0-1mamba
- automatic version update by autodist

* Wed May 05 2021 Automatic Build System <autodist@mambasoft.it> 1.15.0-1mamba
- automatic version update by autodist

* Wed Apr 07 2021 Automatic Build System <autodist@mambasoft.it> 1.14.0-1mamba
- automatic version update by autodist

* Wed Mar 03 2021 Automatic Build System <autodist@mambasoft.it> 1.13.0-1mamba
- automatic version update by autodist

* Wed Feb 03 2021 Automatic Build System <autodist@mambasoft.it> 1.12.0-1mamba
- automatic version update by autodist

* Wed Jan 06 2021 Automatic Build System <autodist@mambasoft.it> 1.11.0-1mamba
- automatic version update by autodist

* Fri Dec 04 2020 Automatic Build System <autodist@mambasoft.it> 1.10.1-1mamba
- automatic version update by autodist

* Thu Dec 03 2020 Automatic Build System <autodist@mambasoft.it> 1.10.0-1mamba
- automatic version update by autodist

* Wed Oct 07 2020 Automatic Build System <autodist@mambasoft.it> 1.9.0-1mamba
- automatic version update by autodist

* Wed Sep 09 2020 Automatic Build System <autodist@mambasoft.it> 1.8.0-1mamba
- automatic version update by autodist

* Sun Aug 23 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.0-2mamba
- remove old egg-info dirs causing errors to launch

* Wed Aug 05 2020 Automatic Build System <autodist@mambasoft.it> 1.7.0-1mamba
- automatic version update by autodist

* Wed Jul 08 2020 Automatic Build System <autodist@mambasoft.it> 1.6.0-1mamba
- automatic version update by autodist

* Wed Jun 03 2020 Automatic Build System <autodist@mambasoft.it> 1.5.0-1mamba
- automatic version update by autodist

* Thu May 07 2020 Automatic Build System <autodist@mambasoft.it> 1.4.0-1mamba
- automatic version update by autodist

* Fri May 01 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.0-3mamba
- added certbot py3 requirements

* Sat Apr 11 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.0-2mamba
- rebuilt with python3

* Wed Mar 04 2020 Automatic Build System <autodist@mambasoft.it> 1.3.0-1mamba
- automatic version update by autodist

* Wed Feb 05 2020 Automatic Build System <autodist@mambasoft.it> 1.2.0-1mamba
- automatic version update by autodist

* Wed Jan 22 2020 Automatic Build System <autodist@mambasoft.it> 1.1.0-1mamba
- automatic version update by autodist

* Sun Dec 08 2019 Automatic Build System <autodist@mambasoft.it> 1.0.0-1mamba
- automatic version update by autodist

* Wed Nov 20 2019 Automatic Build System <autodist@mambasoft.it> 0.40.1-1mamba
- automatic version update by autodist

* Wed Oct 23 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 0.39.0-2mamba
- require python-distro

* Sat Oct 05 2019 Automatic Build System <autodist@mambasoft.it> 0.39.0-1mamba
- automatic version update by autodist

* Tue Sep 10 2019 Automatic Build System <autodist@mambasoft.it> 0.38.0-1mamba
- automatic version update by autodist

* Thu Aug 22 2019 Automatic Build System <autodist@mambasoft.it> 0.37.2-1mamba
- automatic version update by autodist

* Fri Aug 09 2019 Automatic Build System <autodist@mambasoft.it> 0.37.0-1mamba
- automatic version update by autodist

* Sat Jul 20 2019 Automatic Build System <autodist@mambasoft.it> 0.36.0-1mamba
- automatic version update by autodist

* Wed Jun 12 2019 Automatic Build System <autodist@mambasoft.it> 0.35.1-1mamba
- automatic version update by autodist

* Thu Jun 06 2019 Automatic Build System <autodist@mambasoft.it> 0.35.0-1mamba
- automatic version update by autodist

* Wed May 08 2019 Automatic Build System <autodist@mambasoft.it> 0.34.2-1mamba
- automatic version update by autodist

* Tue May 07 2019 Automatic Build System <autodist@mambasoft.it> 0.34.1-1mamba
- automatic version update by autodist

* Fri May 03 2019 Automatic Build System <autodist@mambasoft.it> 0.34.0-1mamba
- automatic version update by autodist

* Sun Apr 07 2019 Automatic Build System <autodist@mambasoft.it> 0.33.1-1mamba
- automatic version update by autodist

* Thu Apr 04 2019 Automatic Build System <autodist@mambasoft.it> 0.33.0-1mamba
- automatic version update by autodist

* Fri Mar 08 2019 Automatic Build System <autodist@mambasoft.it> 0.32.0-1mamba
- automatic version update by autodist

* Sat Feb 09 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 0.31.0-2mamba
- require python-augeas

* Fri Feb 08 2019 Automatic Build System <autodist@mambasoft.it> 0.31.0-1mamba
- automatic version update by autodist

* Mon Jan 28 2019 Automatic Build System <autodist@mambasoft.it> 0.30.2-1mamba
- automatic version update by autodist

* Fri Jan 04 2019 Automatic Build System <autodist@mambasoft.it> 0.30.0-1mamba
- automatic version update by autodist

* Thu Dec 06 2018 Automatic Build System <autodist@mambasoft.it> 0.29.1-1mamba
- automatic version update by autodist

* Thu Dec 06 2018 Automatic Build System <autodist@mambasoft.it> 0.29.0-1mamba
- automatic version update by autodist

* Sun Nov 11 2018 Automatic Build System <autodist@mambasoft.it> 0.28.0-1mamba
- automatic version update by autodist

* Sat Oct 06 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 0.27.1-2mamba
- install apache plugin

* Fri Sep 07 2018 Automatic Build System <autodist@mambasoft.it> 0.27.1-1mamba
- automatic version update by autodist

* Thu Sep 06 2018 Automatic Build System <autodist@mambasoft.it> 0.27.0-1mamba
- automatic version update by autodist

* Mon Aug 06 2018 Automatic Build System <autodist@mambasoft.it> 0.26.1-1mamba
- automatic version update by autodist

* Sun Jul 01 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 0.25.1-2mamba
- require python-requests-toolbelt

* Thu Jun 14 2018 Automatic Build System <autodist@mambasoft.it> 0.25.1-1mamba
- automatic version update by autodist

* Thu Jun 07 2018 Automatic Build System <autodist@mambasoft.it> 0.25.0-1mamba
- automatic version update by autodist

* Thu May 03 2018 Automatic Build System <autodist@mambasoft.it> 0.24.0-1mamba
- automatic version update by autodist

* Mon Apr 09 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 0.23.0-2mamba
- require python-josepy

* Thu Apr 05 2018 Automatic Build System <autodist@mambasoft.it> 0.23.0-1mamba
- automatic version update by autodist

* Tue Mar 20 2018 Automatic Build System <autodist@mambasoft.it> 0.22.2-1mamba
- automatic version update by autodist

* Thu Mar 08 2018 Automatic Build System <autodist@mambasoft.it> 0.22.0-1mamba
- automatic version update by autodist

* Sun Jan 28 2018 Automatic Build System <autodist@mambasoft.it> 0.21.1-1mamba
- automatic version update by autodist

* Thu Jan 18 2018 Automatic Build System <autodist@mambasoft.it> 0.21.0-1mamba
- automatic version update by autodist

* Wed Dec 20 2017 Automatic Build System <autodist@mambasoft.it> 0.20.0-1mamba
- automatic version update by autodist

* Thu Oct 05 2017 Automatic Build System <autodist@mambasoft.it> 0.19.0-1mamba
- automatic version update by autodist

* Thu Sep 21 2017 Automatic Build System <autodist@mambasoft.it> 0.18.2-1mamba
- automatic version update by autodist

* Wed Sep 13 2017 Automatic Build System <autodist@mambasoft.it> 0.18.1-1mamba
- automatic version update by autodist

* Thu Aug 03 2017 Automatic Build System <autodist@mambasoft.it> 0.17.0-1mamba
- automatic version update by autodist

* Fri Jul 07 2017 Automatic Build System <autodist@mambasoft.it> 0.16.0-1mamba
- automatic version update by autodist

* Fri Jun 09 2017 Automatic Build System <autodist@mambasoft.it> 0.15.0-1mamba
- automatic version update by autodist

* Fri May 26 2017 Automatic Build System <autodist@mambasoft.it> 0.14.2-1mamba
- automatic version update by autodist

* Thu May 18 2017 Automatic Build System <autodist@mambasoft.it> 0.14.1-1mamba
- automatic version update by autodist

* Fri May 05 2017 Automatic Build System <autodist@mambasoft.it> 0.14.0-1mamba
- automatic version update by autodist

* Thu Apr 13 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 0.13.0-2mamba
- require python-argparse

* Fri Apr 07 2017 Automatic Build System <autodist@mambasoft.it> 0.13.0-1mamba
- automatic version update by autodist

* Sat Mar 04 2017 Automatic Build System <autodist@mambasoft.it> 0.12.0-1mamba
- automatic version update by autodist

* Sat Feb 04 2017 Automatic Build System <autodist@mambasoft.it> 0.11.1-1mamba
- automatic version update by autodist

* Sun Jan 29 2017 Automatic Build System <autodist@mambasoft.it> 0.10.2-1mamba
- automatic version update by autodist

* Sun Jan 15 2017 Automatic Build System <autodist@mambasoft.it> 0.10.1-1mamba
- automatic version update by autodist

* Thu Jan 12 2017 Automatic Build System <autodist@mambasoft.it> 0.10.0-1mamba
- automatic version update by autodist

* Mon Oct 17 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.3-2mamba
- remove %{_bindir}/letsencrypt symlink

* Mon Oct 17 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.3-1mamba
- update to 0.9.3

* Mon Aug 08 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.1-1mamba
- update to 0.8.1

* Wed Apr 06 2016 Automatic Build System <autodist@mambasoft.it> 0.5.0-1mamba
- automatic version update by autodist

* Fri Mar 04 2016 Automatic Build System <autodist@mambasoft.it> 0.4.2-1mamba
- automatic version update by autodist

* Tue Mar 01 2016 Automatic Build System <autodist@mambasoft.it> 0.4.1-1mamba
- automatic version update by autodist

* Sun Feb 14 2016 Automatic Build System <autodist@mambasoft.it> 0.4.0-1mamba
- automatic version update by autodist

* Thu Jan 28 2016 Automatic Build System <autodist@mambasoft.it> 0.3.0-1mamba
- automatic version update by autodist

* Sat Jan 16 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 0.2.0-1mamba
- update to 0.2.0

* Sat Dec 26 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 0.1.1-2mamba
- upstream patch to fix version check for python-acme

* Wed Dec 16 2015 Automatic Build System <autodist@mambasoft.it> 0.1.1-1mamba
- automatic version update by autodist

* Sun Dec 13 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 0.1.0-4mamba
- require python-setuptools, not python-setuptool

* Tue Dec 08 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 0.1.0-3mamba
- require python-setuptool

* Sat Dec 05 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 0.1.0-2mamba
- added some missing python requires

* Sat Dec 05 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 0.1.0-1mamba
- package created using the webbuild interface
